==> koshoten.net-2.1.2.tar.gz: koshoten-net/catalog/product_info.php <==
<?php
/*
  $Id: product_info.php,v 1.2 2005/08/19 09:48:12 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

  require('includes/application_top.php');

  require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_PRODUCT_INFO);

  $product_info_query = tep_db_query("select p.products_id, pd.products_name, pd.products_subtitle, pd.products_series_title, pd.products_author, pd.products_published, pd.products_publishers, pd.products_volume, p.products_isbn, pd.products_description, pd.products_description2, p.products_model, p.products_quantity, p.products_image, pd.products_url, p.products_price, p.products_tax_class_id, p.products_date_added, p.products_date_available, p.manufacturers_id from " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd where p.products_status = '1' and p.products_id = '" . (int)$HTTP_GET_VARS['products_id'] . "' and pd.products_id = p.products_id and pd.language_id = '" . $languages_id . "'");
  if (!tep_db_num_rows($product_info_query)) { // product not found in database
    $no_product_info = true;
    $product_info_title = TITLE;
  } else {
    $no_product_info = false;
    $product_info = tep_db_fetch_array($product_info_query);
    $product_info_title = TITLE . ' : ' . $product_info['products_name'];
  }
?>
<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
<html <?php echo HTML_PARAMS; ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
<title><?php echo $product_info_title; ?></title>
<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
<link rel="stylesheet" type="text/css" href="general.css">
<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_PRODUCT_INFO, 0, strrpos(FILENAME_PRODUCT_INFO, '.'));?>.css">
<script language="javascript"><!--
function popupWindow(url) {
  window.open(url,'popupWindow','toolbar=no,location=no,directories=no,status=no,menubar=no,scrollbars=no,resizable=yes,copyhistory=no,width=100,height=100,screenX=150,screenY=150,top=150,left=150')
}
//--></script>
</head>
<body>
<div id="bodyWrapper">
<!-- header //-->
<?php require(DIR_WS_INCLUDES . 'header.php'); ?>
<!-- header_eof //-->

<!-- body //-->
<table id="contents">
  <tr>
<!-- left_navigation //-->
<?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
<!-- left_navigation_eof //-->
<!-- body_text //-->
    <td id="mainContents"><?php echo tep_draw_form('cart_quantity', tep_href_link(FILENAME_PRODUCT_INFO, tep_get_all_get_params(array('action')) . 'action=add_product')); ?>
<?php
  if ($no_product_info) {
    // ʤʤȤ
?>
      <div class="noData"><?php echo TEXT_PRODUCT_NOT_FOUND; ?></div>
      <table>
        <tr class="buttonLine">
          <td class="buttonRight"><a href="<?php echo tep_href_link(FILENAME_DEFAULT); ?>"><?php echo tep_image_button('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></a></td>
        </tr>
      </table>
<?php
  } else {
    tep_db_query("update " . TABLE_PRODUCTS_DESCRIPTION . " set products_viewed = products_viewed+1 where products_id = '" . (int)$HTTP_GET_VARS['products_id'] . "' and language_id = '" . $languages_id . "'");
?>
      <div id="productInformation">
      <h1 class="pName"><?php echo $product_info['products_name']; ?></h1>
<?php
    if ((KN_CFG_USE_SUBTITLE == 'true') && ($product_info['products_subtitle'])) {
    	$products_subtitle = '<span class="pSubtitle">' . TEXT_PRODUCTS_SUBTITLE . $product_info['products_subtitle'] . '</span>';
    } else {
    	$products_subtitle = '';
    }
    if ((KN_CFG_USE_SERIES_TITLE == 'true') && ($product_info['products_series_title'])) {
    	$products_series_title = '<span class="pSeriesTitle">' . TEXT_PRODUCTS_SERIES_TITLE . $product_info['products_series_title'] . '</span>';
    } else {
    	$products_series_title = '';
    }
    if (tep_not_null($products_subtitle) and tep_not_null($products_series_title)) {
      echo '      <h2 class="pSubtitleSeriesTitle">' . $products_subtitle . ' ' . $products_series_title . '</h2>' . "\n";
    } elseif (tep_not_null($products_subtitle)) {
      echo '      <h2 class="pSubtitleSeriesTitle">' . $products_subtitle . '</h2>' . "\n";
    } elseif (tep_not_null($products_series_title)) {
      echo '      <h2 class="pSubtitleSeriesTitle">' . $products_series_title . '</h2>' . "\n";
    }

    if (tep_not_null($product_info['products_image'])) {
?>
      <div class="pImage">
<script language="javascript"><!--
document.write('<?php echo '<a href="javascript:popupWindow(\\\'' . tep_href_link(FILENAME_POPUP_IMAGE, 'pID=' . $product_info['products_id']) . '\\\')">' . tep_image(DIR_WS_IMAGES . $product_info['products_image'], addslashes($product_info['products_name']), SUBCATEGORY_IMAGE_WIDTH, SUBCATEGORY_IMAGE_HEIGHT) . '<br>' . TEXT_CLICK_TO_ENLARGE . '</a>'; ?>');
//--></script>
<noscript>
<?php echo '<a href="' . tep_href_link(DIR_WS_IMAGES . $product_info['products_image']) . '">' . tep_image(DIR_WS_IMAGES . $product_info['products_image'], $product_info['products_name'], SUBCATEGORY_IMAGE_WIDTH, SUBCATEGORY_IMAGE_HEIGHT) . '<br>' . TEXT_CLICK_TO_ENLARGE . '</a>'; ?>
</noscript>
</div>
<?php
    }

    if ((KN_CFG_USE_AUTHOR == 'true') && ($product_info['products_author'])) {
      echo '      <div class="pAuthor"><span class="pInfoHeading">' . TEXT_PRODUCTS_AUTHOR . '</span>' . $product_info['products_author'] . '</div>' . "\n";
    }
    if ((KN_CFG_USE_PUBLISHERS == 'true') && ($product_info['products_publishers'])) {
      echo '      <div class="pPublishers"><span class="pInfoHeading">' . TEXT_PRODUCTS_PUBLISHERS . '</span>' . $product_info['products_publishers'] . '</div>' . "\n";
    }
    if ((KN_CFG_USE_VOLUME == 'true') && ($product_info['products_volume'])) {
      echo '      <div class="pVolume"><span class="pInfoHeading">' . TEXT_PRODUCTS_VOLUME . '</span>' . $product_info['products_volume'] . '</div>' . "\n";
    }
    if ((KN_CFG_USE_PUBLISHED == 'true') && ($product_info['products_published'])) {
      echo '      <div class="pPublished"><span class="pInfoHeading">' . TEXT_PRODUCTS_PUBLISHED . '</span>' . $product_info['products_published'] . '</div>' . "\n";
    }
    if ((KN_CFG_USE_ISBN == 'true') && ($product_info['products_isbn'])) {
      echo '      <div class="poIsbn"><span class="pInfoHeading">' . TEXT_PRODUCTS_ISBN . '</span>' . $product_info['products_isbn'] . '</div>' . "\n";
    }
    if ((KN_CFG_USE_WEIGHT == 'true') && ($product_info['products_weight'])) {
      echo '      <div class="pWeight"><span class="pInfoHeading">' . TEXT_PRODUCTS_WEIGHT . '</span>' . $product_info['products_weight'] . '</div>' . "\n";
    }
    if ($product_info['products_description']) {
      echo '      <div class="pDescription">' . TEXT_PRODUCTS_DESCRIPTION . stripslashes($product_info['products_description']) . '</div>' . "\n";
    }
    if (KN_CFG_USE_REVIEWS == 'true') {
      $reviews = tep_db_query("select count(*) as count from " . TABLE_REVIEWS . " where products_id = '" . $HTTP_GET_VARS['products_id'] . "'");
      $reviews_values = tep_db_fetch_array($reviews);
      if ($reviews_values['count'] > 0) {
        echo '      <div class="productInfoCurrentReviews"><span class="pInfoHeading">' . TEXT_CURRENT_REVIEWS . '</span>' . $reviews_values['count'] . '</div>' . "\n";
      }
    }

    if ((KN_CFG_USE_DESCRIPTION2 == 'true') && ($product_info['products_description2'])) {
      echo '      <div class="pDescription2">' . TEXT_PRODUCTS_DESCRIPTION2 . stripslashes($product_info['products_description2']) . '</div>' . "\n";
    }
    $products_attributes_query = tep_db_query("select count(*) as total from " . TABLE_PRODUCTS_OPTIONS . " popt, " . TABLE_PRODUCTS_ATTRIBUTES . " patrib where patrib.products_id='" . (int)$HTTP_GET_VARS['products_id'] . "' and patrib.options_id = popt.products_options_id and popt.language_id = '" . $languages_id . "'");
    $products_attributes = tep_db_fetch_array($products_attributes_query);
    if ($products_attributes['total'] > 0) {
      echo '<div class="pOptionsList"><div class="pOptionsListCaption">' . TEXT_PRODUCT_OPTIONS . '</div>' . "\n";
      $products_options_name_query = tep_db_query("select distinct popt.products_options_id, popt.products_options_name from " . TABLE_PRODUCTS_OPTIONS . " popt, " . TABLE_PRODUCTS_ATTRIBUTES . " patrib where patrib.products_id='" . (int)$HTTP_GET_VARS['products_id'] . "' and patrib.options_id = popt.products_options_id and popt.language_id = '" . $languages_id . "'");
      while ($products_options_name = tep_db_fetch_array($products_options_name_query)) {
        $selected = 0;
        $products_options_array = array();
        echo '<div class="pOptions"><span class="pInfoHeading">' . $products_options_name['products_options_name'] . ':</span>';
        $products_options_query = tep_db_query("select pov.products_options_values_id, pov.products_options_values_name, pa.options_values_price, pa.price_prefix from " . TABLE_PRODUCTS_ATTRIBUTES . " pa, " . TABLE_PRODUCTS_OPTIONS_VALUES . " pov where pa.products_id = '" . (int)$HTTP_GET_VARS['products_id'] . "' and pa.options_id = '" . $products_options_name['products_options_id'] . "' and pa.options_values_id = pov.products_options_values_id and pov.language_id = '" . $languages_id . "'");
        while ($products_options = tep_db_fetch_array($products_options_query)) {
          $products_options_array[] = array('id' => $products_options['products_options_values_id'], 'text' => $products_options['products_options_values_name']);
          if ($products_options['options_values_price'] != '0') {
            $products_options_array[sizeof($products_options_array)-1]['text'] .= ' (' . $products_options['price_prefix'] . $currencies->display_price($products_options['options_values_price'], tep_get_tax_rate($product_info['products_tax_class_id'])) .') ';
          }
        }
        echo tep_draw_pull_down_menu('id[' . $products_options_name['products_options_id'] . ']', $products_options_array, $cart->contents[$HTTP_GET_VARS['products_id']]['attributes'][$products_options_name['products_options_id']]);
        echo '</div>';
      }
      echo '</div>';
    }
    if ($product_info['products_model']) {
      echo '      <div class="pModel"><span class="pInfoHeading">' . TEXT_PRODUCTS_MODEL . '</span>' . $product_info['products_model'] . '</div>' . "\n";
    }

    if ($new_price = tep_get_products_special_price($product_info['products_id'])) {
      echo '      <div class="pPrice"><span class="pInfoHeading">' . TEXT_PRODUCTS_PRICE . '</span><s>' . $currencies->display_price($product_info['products_price'], tep_get_tax_rate($product_info['products_tax_class_id'])) . '</s> <span class="pSpecialPrice">' . $currencies->display_price($new_price, tep_get_tax_rate($product_info['products_tax_class_id'])) . '</span></div>' . "\n";
    } else {
      echo '      <div class="pPrice"><span class="pInfoHeading">' . TEXT_PRODUCTS_PRICE . '</span>' . $currencies->display_price($product_info['products_price'], tep_get_tax_rate($product_info['products_tax_class_id'])) . '</div>' . "\n";
    }
?>
      <table>
        <tr class="buttonLine">
<?php
    if (KN_CFG_USE_REVIEWS == 'true') {
      $reviews = tep_db_query("select count(*) as count from " . TABLE_REVIEWS . " where products_id = '" . $HTTP_GET_VARS['products_id'] . "'");
      $reviews_values = tep_db_fetch_array($reviews);
      if ($reviews_values['count'] > 0) {
?>
          <td class="buttonLeft"><a href="<?php echo tep_href_link(FILENAME_PRODUCT_REVIEWS, substr(tep_get_all_get_params(), 0, -1)); ?>"><?php echo tep_image_button('button_reviews.gif', IMAGE_BUTTON_REVIEWS); ?></a></td>
<?php
      }
    }
?>
          <td class="buttonRight"><?php echo tep_draw_hidden_field('products_id', $product_info['products_id']) . tep_image_submit('button_in_cart.gif', IMAGE_BUTTON_IN_CART); ?></td>
        </tr>
      </table>
<?php
    if ((KN_CFG_USE_URL == 'true') && (tep_not_null($product_info['products_url']))) {
      echo '      <div class="productMoreInfo">' . sprintf(TEXT_MORE_INFORMATION, tep_href_link(FILENAME_REDIRECT, 'action=url&goto=' . urlencode($product_info['products_url']), 'NONSSL', true, false)) . '</div>' . "\n";
    }

    if ((KN_CFG_USE_DATE_AVAILABLE == 'true') && ($product_info['products_date_available'] > date('Y-m-d H:i:s'))) {
      echo '      <div class="pDateAvailable">' . sprintf(TEXT_DATE_AVAILABLE, tep_date_long($product_info['products_date_available'])) . '</div>' . "\n";
    } else {
      if (KN_CFG_DATE_ADDED_DISPLAY == 'true') {
      echo '      <div class="pDateAdded">' . sprintf(TEXT_DATE_ADDED, tep_date_long($product_info['products_date_added'])) . '</div>' . "\n";
      }
    }

    echo '</div>';

    if ((KN_CFG_GETA_ENABLED == 'true') && (KN_CFG_GETA_PRODUCTS_ENABLED == 'true')) {
      //GETAե
      require('../geta_work/geta_cfg.php');
      $g_products_id = (int)$HTTP_GET_VARS['products_id'];
      include(DIR_WS_MODULES . FILENAME_GETA_PRODUCTS);
    }

    if (KN_CFG_ALSO_PURCHASED_DISPLAY == 'true') {
      if ( (USE_CACHE == 'true') && !SID ) {
        echo tep_cache_also_purchased(3600);
      } else {
        include(DIR_WS_MODULES . FILENAME_ALSO_PURCHASED_PRODUCTS);
      }
    }
  }
?>
    </form></td>
<!-- body_text_eof //-->
<!-- right_navigation //-->
<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
<!-- right_navigation_eof //-->
  </tr>
</table>
<!-- body_eof //-->
<!-- footer //-->
<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
<!-- footer_eof //-->
</div>
</body>
</html>
<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>

==> koshoten.net-2.1.4.tar.gz: koshoten-net/catalog/product_info.php <==
<?php
/*
  $Id: product_info.php,v 1.3 2005/09/22 01:12:02 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

  require('includes/application_top.php');

  require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_PRODUCT_INFO);

  $product_info_query = tep_db_query("select p.products_id, pd.products_name, pd.products_subtitle, pd.products_series_title, pd.products_author, pd.products_published, pd.products_publishers, pd.products_volume, p.products_isbn, pd.products_description, pd.products_description2, p.products_model, p.products_quantity, p.products_image, pd.products_url, p.products_price, p.products_tax_class_id, p.products_date_added, p.products_date_available, p.manufacturers_id from " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd where p.products_status = '1' and p.products_id = '" . (int)$HTTP_GET_VARS['products_id'] . "' and pd.products_id = p.products_id and pd.language_id = '" . $languages_id . "'");
  if (!tep_db_num_rows($product_info_query)) { // product not found in database
    $no_product_info = true;
    $product_info_title = TITLE;
  } else {
    $no_product_info = false;
    $product_info = tep_db_fetch_array($product_info_query);
    $product_info_title = TITLE . ' : ' . $product_info['products_name'];
  }
?>
<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
<html <?php echo HTML_PARAMS; ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
<title><?php echo $product_info_title; ?></title>
<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
<link rel="stylesheet" type="text/css" href="general.css">
<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_PRODUCT_INFO, 0, strrpos(FILENAME_PRODUCT_INFO, '.'));?>.css">
<script language="javascript"><!--
function popupWindow(url) {
  window.open(url,'popupWindow','toolbar=no,location=no,directories=no,status=no,menubar=no,scrollbars=no,resizable=yes,copyhistory=no,width=100,height=100,screenX=150,screenY=150,top=150,left=150')
}
//--></script>
</head>
<body>
<div id="bodyWrapper">
<!-- header //-->
<?php require(DIR_WS_INCLUDES . 'header.php'); ?>
<!-- header_eof //-->

<!-- body //-->
<table id="contents">
  <tr>
<!-- left_navigation //-->
<?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
<!-- left_navigation_eof //-->
<!-- body_text //-->
    <td id="mainContents"><?php echo tep_draw_form('cart_quantity', tep_href_link(FILENAME_PRODUCT_INFO, tep_get_all_get_params(array('action')) . 'action=add_product')); ?>
<?php
  if ($no_product_info) {
    // ʤʤȤ
?>
      <div class="noData"><?php echo TEXT_PRODUCT_NOT_FOUND; ?></div>
      <table>
        <tr class="buttonLine">
          <td class="buttonRight"><a href="<?php echo tep_href_link(FILENAME_DEFAULT); ?>"><?php echo tep_image_button('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></a></td>
        </tr>
      </table>
<?php
  } else {
    tep_db_query("update " . TABLE_PRODUCTS_DESCRIPTION . " set products_viewed = products_viewed+1 where products_id = '" . (int)$HTTP_GET_VARS['products_id'] . "' and language_id = '" . $languages_id . "'");
?>
      <div id="productInformation">
      <h1 class="pName"><?php echo $product_info['products_name']; ?></h1>
<?php
    if ((KN_CFG_USE_SUBTITLE == 'true') && ($product_info['products_subtitle'])) {
    	$products_subtitle = '<span class="pSubtitle">' . TEXT_PRODUCTS_SUBTITLE . $product_info['products_subtitle'] . '</span>';
    } else {
    	$products_subtitle = '';
    }
    if ((KN_CFG_USE_SERIES_TITLE == 'true') && ($product_info['products_series_title'])) {
    	$products_series_title = '<span class="pSeriesTitle">' . TEXT_PRODUCTS_SERIES_TITLE . $product_info['products_series_title'] . '</span>';
    } else {
    	$products_series_title = '';
    }
    if (tep_not_null($products_subtitle) and tep_not_null($products_series_title)) {
      echo '      <h2 class="pSubtitleSeriesTitle">' . $products_subtitle . ' ' . $products_series_title . '</h2>' . "\n";
    } elseif (tep_not_null($products_subtitle)) {
      echo '      <h2 class="pSubtitleSeriesTitle">' . $products_subtitle . '</h2>' . "\n";
    } elseif (tep_not_null($products_series_title)) {
      echo '      <h2 class="pSubtitleSeriesTitle">' . $products_series_title . '</h2>' . "\n";
    }

    if (tep_not_null($product_info['products_image'])) {
?>
      <div class="pImage">
<script language="javascript"><!--
document.write('<?php echo '<a href="javascript:popupWindow(\\\'' . tep_href_link(FILENAME_POPUP_IMAGE, 'pID=' . $product_info['products_id']) . '\\\')">' . tep_image(DIR_WS_IMAGES . $product_info['products_image'], addslashes($product_info['products_name']), SUBCATEGORY_IMAGE_WIDTH, SUBCATEGORY_IMAGE_HEIGHT) . '<br>' . TEXT_CLICK_TO_ENLARGE . '</a>'; ?>');
//--></script>
<noscript>
<?php echo '<a href="' . tep_href_link(DIR_WS_IMAGES . $product_info['products_image']) . '">' . tep_image(DIR_WS_IMAGES . $product_info['products_image'], $product_info['products_name'], SUBCATEGORY_IMAGE_WIDTH, SUBCATEGORY_IMAGE_HEIGHT) . '<br>' . TEXT_CLICK_TO_ENLARGE . '</a>'; ?>
</noscript>
</div>
<?php
    }

    if ((KN_CFG_USE_AUTHOR == 'true') && ($product_info['products_author'])) {
      echo '      <div class="pAuthor"><span class="pInfoHeading">' . TEXT_PRODUCTS_AUTHOR . '</span>' . $product_info['products_author'] . '</div>' . "\n";
    }
    if ((KN_CFG_USE_PUBLISHERS == 'true') && ($product_info['products_publishers'])) {
      echo '      <div class="pPublishers"><span class="pInfoHeading">' . TEXT_PRODUCTS_PUBLISHERS . '</span>' . $product_info['products_publishers'] . '</div>' . "\n";
    }
    if ((KN_CFG_USE_VOLUME == 'true') && ($product_info['products_volume'])) {
      echo '      <div class="pVolume"><span class="pInfoHeading">' . TEXT_PRODUCTS_VOLUME . '</span>' . $product_info['products_volume'] . '</div>' . "\n";
    }
    if ((KN_CFG_USE_PUBLISHED == 'true') && ($product_info['products_published'])) {
      echo '      <div class="pPublished"><span class="pInfoHeading">' . TEXT_PRODUCTS_PUBLISHED . '</span>' . $product_info['products_published'] . '</div>' . "\n";
    }
    if ((KN_CFG_USE_ISBN == 'true') && ($product_info['products_isbn'])) {
      echo '      <div class="poIsbn"><span class="pInfoHeading">' . TEXT_PRODUCTS_ISBN . '</span>' . $product_info['products_isbn'] . '</div>' . "\n";
    }
    if ((KN_CFG_USE_WEIGHT == 'true') && ($product_info['products_weight'])) {
      echo '      <div class="pWeight"><span class="pInfoHeading">' . TEXT_PRODUCTS_WEIGHT . '</span>' . $product_info['products_weight'] . '</div>' . "\n";
    }
    if ($product_info['products_description']) {
      echo '      <div class="pDescription">' . TEXT_PRODUCTS_DESCRIPTION . nl2br(stripslashes($product_info['products_description'])) . '</div>' . "\n";
    }
    if (KN_CFG_USE_REVIEWS == 'true') {
      $reviews = tep_db_query("select count(*) as count from " . TABLE_REVIEWS . " where products_id = '" . $HTTP_GET_VARS['products_id'] . "'");
      $reviews_values = tep_db_fetch_array($reviews);
      if ($reviews_values['count'] > 0) {
        echo '      <div class="productInfoCurrentReviews"><span class="pInfoHeading">' . TEXT_CURRENT_REVIEWS . '</span>' . $reviews_values['count'] . '</div>' . "\n";
      }
    }

    if ((KN_CFG_USE_DESCRIPTION2 == 'true') && ($product_info['products_description2'])) {
      echo '      <div class="pDescription2">' . TEXT_PRODUCTS_DESCRIPTION2 . nl2br(stripslashes($product_info['products_description2'])) . '</div>' . "\n";
    }
    $products_attributes_query = tep_db_query("select count(*) as total from " . TABLE_PRODUCTS_OPTIONS . " popt, " . TABLE_PRODUCTS_ATTRIBUTES . " patrib where patrib.products_id='" . (int)$HTTP_GET_VARS['products_id'] . "' and patrib.options_id = popt.products_options_id and popt.language_id = '" . $languages_id . "'");
    $products_attributes = tep_db_fetch_array($products_attributes_query);
    if ($products_attributes['total'] > 0) {
      echo '<div class="pOptionsList"><div class="pOptionsListCaption">' . TEXT_PRODUCT_OPTIONS . '</div>' . "\n";
      $products_options_name_query = tep_db_query("select distinct popt.products_options_id, popt.products_options_name from " . TABLE_PRODUCTS_OPTIONS . " popt, " . TABLE_PRODUCTS_ATTRIBUTES . " patrib where patrib.products_id='" . (int)$HTTP_GET_VARS['products_id'] . "' and patrib.options_id = popt.products_options_id and popt.language_id = '" . $languages_id . "'");
      while ($products_options_name = tep_db_fetch_array($products_options_name_query)) {
        $selected = 0;
        $products_options_array = array();
        echo '<div class="pOptions"><span class="pInfoHeading">' . $products_options_name['products_options_name'] . ':</span>';
        $products_options_query = tep_db_query("select pov.products_options_values_id, pov.products_options_values_name, pa.options_values_price, pa.price_prefix from " . TABLE_PRODUCTS_ATTRIBUTES . " pa, " . TABLE_PRODUCTS_OPTIONS_VALUES . " pov where pa.products_id = '" . (int)$HTTP_GET_VARS['products_id'] . "' and pa.options_id = '" . $products_options_name['products_options_id'] . "' and pa.options_values_id = pov.products_options_values_id and pov.language_id = '" . $languages_id . "'");
        while ($products_options = tep_db_fetch_array($products_options_query)) {
          $products_options_array[] = array('id' => $products_options['products_options_values_id'], 'text' => $products_options['products_options_values_name']);
          if ($products_options['options_values_price'] != '0') {
            $products_options_array[sizeof($products_options_array)-1]['text'] .= ' (' . $products_options['price_prefix'] . $currencies->display_price($products_options['options_values_price'], tep_get_tax_rate($product_info['products_tax_class_id'])) .') ';
          }
        }
        echo tep_draw_pull_down_menu('id[' . $products_options_name['products_options_id'] . ']', $products_options_array, $cart->contents[$HTTP_GET_VARS['products_id']]['attributes'][$products_options_name['products_options_id']]);
        echo '</div>';
      }
      echo '</div>';
    }
    if ($product_info['products_model']) {
      echo '      <div class="pModel"><span class="pInfoHeading">' . TEXT_PRODUCTS_MODEL . '</span>' . $product_info['products_model'] . '</div>' . "\n";
    }

    if ($new_price = tep_get_products_special_price($product_info['products_id'])) {
      echo '      <div class="pPrice"><span class="pInfoHeading">' . TEXT_PRODUCTS_PRICE . '</span><s>' . $currencies->display_price($product_info['products_price'], tep_get_tax_rate($product_info['products_tax_class_id'])) . '</s> <span class="pSpecialPrice">' . $currencies->display_price($new_price, tep_get_tax_rate($product_info['products_tax_class_id'])) . '</span></div>' . "\n";
    } else {
      echo '      <div class="pPrice"><span class="pInfoHeading">' . TEXT_PRODUCTS_PRICE . '</span>' . $currencies->display_price($product_info['products_price'], tep_get_tax_rate($product_info['products_tax_class_id'])) . '</div>' . "\n";
    }
?>
      <table>
        <tr class="buttonLine">
<?php
    if (KN_CFG_USE_REVIEWS == 'true') {
      $reviews = tep_db_query("select count(*) as count from " . TABLE_REVIEWS . " where products_id = '" . $HTTP_GET_VARS['products_id'] . "'");
      $reviews_values = tep_db_fetch_array($reviews);
      if ($reviews_values['count'] > 0) {
?>
          <td class="buttonLeft"><a href="<?php echo tep_href_link(FILENAME_PRODUCT_REVIEWS, substr(tep_get_all_get_params(), 0, -1)); ?>"><?php echo tep_image_button('button_reviews.gif', IMAGE_BUTTON_REVIEWS); ?></a></td>
<?php
      }
    }
?>
          <td class="buttonRight"><?php echo tep_draw_hidden_field('products_id', $product_info['products_id']) . tep_image_submit('button_in_cart.gif', IMAGE_BUTTON_IN_CART); ?></td>
        </tr>
      </table>
<?php
    if ((KN_CFG_USE_URL == 'true') && (tep_not_null($product_info['products_url']))) {
      echo '      <div class="productMoreInfo">' . sprintf(TEXT_MORE_INFORMATION, tep_href_link(FILENAME_REDIRECT, 'action=url&goto=' . urlencode($product_info['products_url']), 'NONSSL', true, false)) . '</div>' . "\n";
    }

    if ((KN_CFG_USE_DATE_AVAILABLE == 'true') && ($product_info['products_date_available'] > date('Y-m-d H:i:s'))) {
      echo '      <div class="pDateAvailable">' . sprintf(TEXT_DATE_AVAILABLE, tep_date_long($product_info['products_date_available'])) . '</div>' . "\n";
    } else {
      if (KN_CFG_DATE_ADDED_DISPLAY == 'true') {
      echo '      <div class="pDateAdded">' . sprintf(TEXT_DATE_ADDED, tep_date_long($product_info['products_date_added'])) . '</div>' . "\n";
      }
    }

    echo '</div>';

    if ((KN_CFG_GETA_ENABLED == 'true') && (KN_CFG_GETA_PRODUCTS_ENABLED == 'true')) {
      //GETAե
      require('../geta_work/geta_cfg.php');
      $g_products_id = (int)$HTTP_GET_VARS['products_id'];
      include(DIR_WS_MODULES . FILENAME_GETA_PRODUCTS);
    }

    if (KN_CFG_ALSO_PURCHASED_DISPLAY == 'true') {
      if ( (USE_CACHE == 'true') && !SID ) {
        echo tep_cache_also_purchased(3600);
      } else {
        include(DIR_WS_MODULES . FILENAME_ALSO_PURCHASED_PRODUCTS);
      }
    }
  }
?>
    </form></td>
<!-- body_text_eof //-->
<!-- right_navigation //-->
<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
<!-- right_navigation_eof //-->
  </tr>
</table>
<!-- body_eof //-->
<!-- footer //-->
<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
<!-- footer_eof //-->
</div>
</body>
</html>
<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
